---
title: <span class="badge object-type-scalar"></span> DegreesPerSecond
---
# <span class="badge object-type-scalar"></span> DegreesPerSecond

Rotational Speed: Degrees per second (°/s)

## Definition

```python
# Rotational Speed: Degrees per second (°/s)
DegreesPerSecond: typing.Literal["rotdegs"] = "rotdegs"
```
